# DataMarket scraping core

------------------------------------------------------
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


Utilities that integrate advance scraping knowledge into just one library.

## Installation

To install this library in your Python environment:

`pip install datamarket`

## Documentation
